# aeneas.cdtw

**aeneas.cdtw** is a Python C extension for computing the DTW.

## API

See the [__init__.py](__init__.py) file.

## Compiling the Python C extension locally

```bash
$ make py
```

## Compiling the pure C driver program

```bash
$ make driver
```

## Testing the pure C driver program

```bash
$ make test
```



